/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsMsgSMIMECID_h__
#define nsMsgSMIMECID_h__

#define NS_MSGCOMPOSESECURE_CID                      \
  { /* 54976882-7421-4286-8ecc-46373f15d7b5 */       \
    0x54976882, 0x7421, 0x4286, {                    \
      0x8e, 0xcc, 0x46, 0x37, 0x3f, 0x15, 0xd7, 0xb5 \
    }                                                \
  }

#define NS_SMIMEJSHELPER_CONTRACTID \
  "@mozilla.org/messenger-smime/smimejshelper;1"

#define NS_SMIMEJSJELPER_CID                         \
  { /* d57d928c-60e4-4f81-999d-5c762e611205 */       \
    0xd57d928c, 0x60e4, 0x4f81, {                    \
      0x99, 0x9d, 0x5c, 0x76, 0x2e, 0x61, 0x12, 0x05 \
    }                                                \
  }

#define NS_CMSDECODERJS_CONTRACTID "@mozilla.org/nsCMSDecoderJS;1"

#define NS_CMSDECODERJS_CID                          \
  { /* fb62c8ed-b875-488a-be35-ab9764bcad25 */       \
    0xfb62c8ed, 0xb875, 0x488a, {                    \
      0xbe, 0x35, 0xab, 0x97, 0x64, 0xbc, 0xad, 0x25 \
    }                                                \
  }

#define NS_SMIMEENCRYPTURISERVICE_CONTRACTID \
  "@mozilla.org/messenger-smime/smime-encrypted-uris-service;1"

#define NS_SMIMEENCRYPTURISERVICE_CID                \
  { /* a0134d58-018f-4d40-a099-fa079e5024a6 */       \
    0xa0134d58, 0x018f, 0x4d40, {                    \
      0xa0, 0x99, 0xfa, 0x07, 0x9e, 0x50, 0x24, 0xa6 \
    }                                                \
  }

#endif  // nsMsgSMIMECID_h__
